@@ -195,15 +195,15 @@ any later version. Please see COPYING for more details.\n\n""") % \
     def festival_connect(self, host="localhost", port=1314):
         """
         Try to connect to festival and determine whether it is possible.
-        On success self.festival_socket is initialized with the openned socket.
+        On success self.festival_socket is initialized with the opened socket.
         """
         self.festival_socket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
         try:
             self.festival_socket.connect((socket.gethostbyname(host), port))
         except socket.error as e:
-            (num, reson) = e.args
+            (num, reason) = e.args
             report(_("""ERROR: It was not possible to connect to Festival on the
-given host and port. Connection failed with error %d : %s .""" % (num, reson)))
+given host and port. Connection failed with error %d : %s .""" % (num, reason)))
             report(_("""Hint: Most likely, your Festival server is not running now
 or not at the default port %d.
 
